#
# spec file for package python-pyasn1-modules
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyasn1-modules
Version:        0.4.1
Release:        1.3
Summary:        Collection of protocols modules written in ASN.1 language
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pyasn1/pyasn1-modules
Source:         https://files.pythonhosted.org/packages/source/p/pyasn1-modules/pyasn1_modules-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/pyasn1/pyasn1-modules/pull/22 Stop using pyasn1.compat.octets
Patch0:         pyasn1-061.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyasn1 >= 0.4.7}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyasn1 >= 0.4.7
BuildArch:      noarch
%python_subpackages

%description
This is an implementation of ASN.1 types and codecs in Python programming
language. It has been first written to support particular protocol (SNMP) but
then generalized to be suitable for a wide range of protocols based on ASN.1
specification.

%prep
%autosetup -p1 -n pyasn1_modules-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.txt README.md
%{python_sitelib}/pyasn1_modules
%{python_sitelib}/pyasn1_modules-%{version}.dist-info

%changelog
* Mon Oct  7 2024 Markéta Machová <mmachova@suse.com>
- Update to 0.4.1
  * Added support for Python 3.13
- Add upstream pyasn1-061.patch to fix tests with recent pyasn1
* Thu Mar 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.4.0:
  * Added support for Python 3.11, 3.12
  * Removed support for EOL Pythons 2.7, 3.6, 3.7
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.0:
  * Added support for Python 3.8, 3.9, 3.10, 3.11
  * Removed support for EOL Pythons 2.4, 2.5, 2.6, 3.2, 3.3, 3.4,
    3.5
  * Added support for PyPy 3.7, 3.8, 3.9
  * Modernized packaging and testing. pyasn1-modules now uses
    ``setup.cfg``, ``pyproject.toml``,
  * PyPI package ownership for `pyasn1` and `pyasn1-module` has
    been transfered to *Christian Heimes* and *Simon Pichugin* in
  * The upstream repositories for `pyasn1` and `pyasn1-modules`
    are now in the GitHub organization https://github.com/pyasn1/.
  * Added tox runner with a handful of basic jobs
  * Add RFC3125 providing Electronic Signature Policies
  * Add RFC5126 providing CMS Advanced Electronic Signatures
  * Improve test routines for RFC5126
  * Add RFC4387 providing Certificate Store Access via HTTP
  * Changed assertion in unit tests from Python built-in to
    `unittest` provided
  * Add RFC8692 providing Algorithm Identifiers for RSASSA-PSS
    and ECDSA Using SHAKEs
  * Add RFC5753 providing CMS Elliptic Curve Cryptography
    Algorithms
  * Add RFC3820 providing Proxy Certificates
  * Add RFC3370 providing Cryptographic Message Syntax (CMS)
    Algorithms
  * Add RFC3537 providing HMAC Key Wrapping
  * Add RFC3739 providing Qualified Certificates
  * Add RFC2876 providing KEA and SKIPJACK for CMS
  * Add RFC3058 providing IDEA Encryption Algorithm for CMS
  * Add RFC3657 providing Camellia Encryption Algorithm for CMS
  * Add RFC4010 providing SEED Encryption Algorithm for CMS
  * Add RFC4357 providing Additional Cryptographic Algorithms for
  * Add RFC4490 providing GOST 28147-89, GOST R 34.11-94, GOST R
    34.10-94, and GOST R 34.10-2001 Algorithms for CMS
  * Add RFC4491 providing GOST R 34.10-94, GOST R 34.10-2001, and
    GOST R 34.11-94 Algorithms for certificates and CRLs
  * Add RFC8696 providing using Pre-Shared Key (PSK) in the CMS
  * Add RFC5639 providing identifiers for the Brainpool curves in
    Elliptic Curve Cryptography
  * Add RFC5697 providing Other Certificates Extension
  * Add RFC4683 providing Subject Identification Method (SIM)
  * Add RFC4476 providing Attribute Certificate Policies
    Extension
  * Add RFC5636 providing Traceable Anonymous Certificate
  * Add RFC5752 providing Multiple Signatures attribute for CMS
  * Add RFC5275 providing CMS Symmetric Key Management and
    Distribution
  * Add RFC8702 providing SHAKE One-way Hash Functions in the CMS
  * Add RFC8708 providing HSS/LMS Hash-based Signature Algorithm
    for CMS
  * Advance copyright statement to year 2020
  * Add RFC8769 providing CBOR and CBOR Sequence content types
    for CMS
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Feb  8 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specific in %%files section
- update to version 0.2.8:
  * Improve test routines for modules that use certificate extensions
  * Improve test for RFC3709 with a real world certificate
  * Added RFC7633 providing TLS Features Certificate Extension
  * Added RFC7229 providing OIDs for Test Certificate Policies
  * Added tests for RFC3280, RFC3281, RFC3852, and RFC4211
  * Added RFC6960 providing Online Certificate Status Protocol (OCSP)
  * Added RFC6955 providing Diffie-Hellman Proof-of-Possession
    Algorithms
  * Updated the handling of maps for use with openType for RFC 3279
  * Added RFC6486 providing RPKI Manifests
  * Added RFC6487 providing Profile for X.509 PKIX Resource
    Certificates
  * Added RFC6170 providing Certificate Image in the Internet X.509
    Public Key Infrastructure, and import the object identifier into
    RFC3709.
  * Added RFC6187 providing Certificates for Secure Shell
    Authentication
  * Added RFC6482 providing RPKI Route Origin Authorizations (ROAs)
  * Added RFC6664 providing S/MIME Capabilities for Public Keys
  * Added RFC6120 providing Extensible Messaging and Presence Protocol
    names in certificates
  * Added RFC4985 providing Subject Alternative Name for expression of
    service names in certificates
  * Added RFC5924 providing Extended Key Usage for Session Initiation
    Protocol (SIP) in X.509 certificates
  * Added RFC5916 providing Device Owner Attribute
  * Added RFC7508 providing Securing Header Fields with S/MIME
  * Update RFC8226 to use ComponentPresentConstraint() instead of the
    previous work around
  * Add RFC2631 providing OtherInfo for Diffie-Hellman Key Agreement
  * Add RFC3114 providing test values for the S/MIME Security Label
  * Add RFC5755 providing Attribute Certificate Profile for
    Authorization
  * Add RFC5913 providing Clearance Attribute and Authority Clearance
    Constraints Certificate Extension
  * Add RFC5917 providing Clearance Sponsor Attribute
  * Add RFC4043 providing Internet X.509 PKI Permanent Identifier
  * Add RFC7585 providing Network Access Identifier (NAI) Realm Name
    for Certificates
  * Update RFC3770 to support openType for attributes and reported
    errata
  * Add RFC4334 providing Certificate Extensions and Attributes for
    Authentication in PPP and Wireless LAN Networks
* Sun Nov 17 2019 Michael Ströder <michael@stroeder.com>
- Update to 0.2.7
  * various RFC enhancements, see CHANGES.txt
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.6:
  * various RFC enhancements, see CHANGES.txt
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.5:
  - Added RFC3560 providing RSAES-OAEP Key Transport Algorithm
    in CMS
  - Added RFC6019 providing BinaryTime - an alternate format
    for representing Date and Time
  - RFC3565 superseded by RFC5649
  - Added RFC5480 providng Elliptic Curve Cryptography Subject
    Public Key Information
  - Added RFC8520 providing X.509 Extensions for MUD URL and
    MUD Signer
  - Added RFC3161 providing Time-Stamp Protocol support
  - Added RFC3709 providing Logotypes in X.509 Certificates
  - Added RFC3274 providing CMS Compressed Data Content Type
  - Added RFC4073 providing Multiple Contents protection
    with CMS
- Execute testsuite
* Mon Jan 28 2019 Michael Ströder <michael@stroeder.com>
- update to version 0.2.4
  Revision 0.2.4:
- Added modules for RFC8226 implementing JWT Claim Constraints
  and TN Authorization List for X.509 certificate extensions
- Fixed bug in `rfc5280.AlgorithmIdentifier` ANY type definition
  Revision 0.2.3:
- Added modules for RFC5083 and RFC5084 (CMS)
- Copyright notice extended to the year 2019
* Tue Jul  3 2018 michael@stroeder.com
- update to version 0.2.2:
  * Copyright notice extended to the year 2018
  * Migrated references from SourceForge
  * rfc2986 module added
* Sun Nov 26 2017 arun@gmx.de
- update to version 0.2.1:
  * Allow ANY DEFINED BY objects expanding automatically if requested
  * Imports PEP8'ed
* Thu Oct 12 2017 michael@stroeder.com
- Update to upstream release 0.1.5
  * OCSP response blob fixed in test
  * Fixed wrong OCSP ResponderID components tagging
* Thu Sep  7 2017 michael@stroeder.com
- Update to upstream release 0.1.4
  * more onversion pinning
* Thu Sep  7 2017 michael@stroeder.com
- Update to upstream release 0.1.2
  * Tests refactored into proper unit tests
  * pem.readBase64fromText() convenience function added
  * Pinned to pyasn1 0.3.4+
* Tue Aug 15 2017 michael@stroeder.com
- Update to upstream release 0.0.11
  * Fixed typo in ASN.1 definitions at rfc2315.py
* Sat Jul 29 2017 michael@stroeder.com
- Updated project URL
- Update to upstream release 0.0.10
  * Fixed SequenceOf initializer to pass now-mandatory componentType
    keyword argument (since pyasn1 0.3.1)
  * Temporarily fixed recursive ASN.1 type definition to work with
    pyasn1 0.3.1+. This is going to be fixed properly shortly.
* Wed Jun 14 2017 michael@stroeder.com
- Update to upstream release 0.0.9
  * More CRL data structures added (RFC3279)
  * Added X.509 certificate extensions map
  * Added X.509 attribute type map
  * Fix to __doc__ use in setup.py to make -O0 installation mode working
  * Copyright added to source files
  * More PEP-8'ing done on the code
  * Author's e-mail changed
* Thu Mar 16 2017 tbechtold@suse.com
- Switch to singlespec approach
* Tue Dec 29 2015 michael@stroeder.com
- Update to upstream release 0.0.8
  - Wheel distribution format now supported
  - Fix to misspelled rfc2459.id_at_sutname variable
  - Fix to misspelled rfc2459.NameConstraints component tag ID
  - Fix to misspelled rfc2459.GeneralSubtree component default status
* Thu Aug 13 2015 michael@stroeder.com
- Added file ext .txt to doc files like in upstream
- Update to upstream release 0.0.7
  - Extensions added to text files, CVS attic flushed.
  - Fix to rfc2459.BasicConstraints syntax.
* Sat Jul  4 2015 michael@stroeder.com
- Update to upstream release 0.0.6
  - Typo fix to id_kp_serverAuth object value
  - A test case for indefinite length encoding eliminated as it's
    forbidden in DER.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue May  7 2013 michael@stroeder.com
- Update to upstream release 0.0.5
  Revision 0.0.5
- License updated to vanilla BSD 2-Clause to ease package use
  (http://opensource.org/licenses/BSD-2-Clause).
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Fri Jul 27 2012 michael@stroeder.com
- Update to upstream release 0.0.4
  The pyasn1-modules collection now includes Certificate Management Protocol
  (RFC4210) data structures.
* Mon Apr 23 2012 michael@stroeder.com
- Update to upstream release 0.0.3
* Fri Mar 23 2012 michael@stroeder.com
- Initial submission of upstream release 0.0.2
